/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package ring;

import java.text.DecimalFormat;
import java.text.NumberFormat;

import org.objectweb.dream.aaa.agent.Agent;
import org.objectweb.dream.aaa.agent.AgentId;
import org.objectweb.dream.aaa.agent.Notification;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * TODO Add class comment
 */
public class RingAgent extends Agent
{
  protected long         nbRing           = 0;
  protected long         nbRingSinceLast  = 0;
  protected int          nbDisplay        = 0;
  protected long         lastTimestamp    = 0;
  protected long         firstTimestamp   = 0;
  protected double       last5sum         = 0;
  protected double       last10sum        = 0;
  protected double       last15sum        = 0;
  protected double[]     last15Rates      = new double[15];
  protected int          last15RatesIndex = 0;
  protected NumberFormat rateFormatter;

  protected AgentId      nextAgent;

  /**
   * @see Agent#Agent(short, short)
   */
  public RingAgent(short local, short to)
  {
    super(local, to, "RingAgent");
    rateFormatter = new DecimalFormat(".00");
  }

  /**
   * @see Agent#react(AgentId, Notification)
   */
  public void react(AgentId from, Notification not) throws Exception
  {
    if (not instanceof PrintStatRequestNotif)
    {

      if (nbDisplay % 50 == 0)
      {
        // print header.
        System.out
            .println("|-------|----------|----------|----------|----------|----------|-------------|");
        System.out
            .println("|       |     last |   last 5 |  last 10 |  last 15 |   global |     nb ring |");
        System.out
            .println("|-------|----------|----------|----------|----------|----------|-------------|");
      }
      nbDisplay++;
      long nextTimestamp = System.currentTimeMillis();
      if (lastTimestamp == 0)
      {
        lastTimestamp = firstTimestamp;
      }

      nbRing += nbRingSinceLast;
      double rate = nbRingSinceLast * 1000.0 / (nextTimestamp - lastTimestamp);
      double globalRate = nbRing * 1000.0 / (nextTimestamp - firstTimestamp);
      last5sum += rate;
      last10sum += rate;
      last15sum += rate;
      if (nbDisplay >= 5)
      {
        last5sum -= last15Rates[(last15RatesIndex + 10) % 15];
        if (nbDisplay >= 10)
        {
          last10sum -= last15Rates[(last15RatesIndex + 5) % 15];
          if (nbDisplay >= 15)
          {
            last15sum -= last15Rates[last15RatesIndex];
          }
        }
      }
      last15Rates[last15RatesIndex] = rate;
      last15RatesIndex = (last15RatesIndex + 1) % 15;
      nbRingSinceLast = 0;
      lastTimestamp = nextTimestamp;

      StringBuffer buffer = new StringBuffer("| ");
      formatLong(buffer, nbDisplay, 5).append(" | ");
      formatDouble(buffer, rate, 8).append(" | ");
      if (nbDisplay < 5)
      {
        buffer.append("         |          |          | ");
      }
      else
      {
        formatDouble(buffer, last5sum / 5, 8).append(" | ");
        if (nbDisplay < 10)
        {
          buffer.append("         |          | ");
        }
        else
        {
          formatDouble(buffer, last10sum / 10, 8).append(" | ");
          if (nbDisplay < 15)
          {
            buffer.append("         | ");
          }
          else
          {
            formatDouble(buffer, last15sum / 15, 8).append(" | ");
          }
        }
      }
      formatDouble(buffer, globalRate, 8).append(" | ");
      formatLong(buffer, nbRing, 11).append(" |");
      System.out.println(buffer);
    }
    else
    {
      if (logger.isLoggable(BasicLevel.DEBUG))
      {
        logger.log(BasicLevel.DEBUG, getId()
            + " forward ring notification");
      }
      if (firstTimestamp == 0)
      {
        firstTimestamp = System.currentTimeMillis();
      }
      nbRingSinceLast++;
      sendTo(nextAgent, not);
    }
  }

  private StringBuffer formatLong(StringBuffer buffer, long value, int nbChar)
  {
    String s = Long.toString(value);
    for (int i = s.length(); i < nbChar; i++)
    {
      buffer.append(' ');
    }
    return buffer.append(s);
  }

  private StringBuffer formatDouble(StringBuffer buffer, double value,
      int nbChar)
  {
    String s = rateFormatter.format(value);
    for (int i = s.length(); i < nbChar; i++)
    {
      buffer.append(' ');
    }
    return buffer.append(s);
  }
}