/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

/*
 * Parts of this code are copyright:
 * 
 * The contents of this file are subject to the Joram Public License, as defined
 * by the file JORAM_LICENSE.TXT
 * 
 * You may not use this file except in compliance with the License. You may
 * obtain a copy of the License on the Objectweb web site (www.objectweb.org).
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific terms governing rights and limitations under the License.
 * 
 * The Original Code is Joram, including the java packages fr.dyade.aaa.agent,
 * fr.dyade.aaa.util, fr.dyade.aaa.ip, fr.dyade.aaa.mom, and fr.dyade.aaa.joram,
 * released May 24, 2000.
 * 
 * The Initial Developer of the Original Code is Dyade. The Original Code and
 * portions created by Dyade are Copyright Bull and Copyright INRIA. All Rights
 * Reserved.
 * 
 * The present code contributor is INRIA Rhone-Alpes.
 */

package org.objectweb.dream.aaa.agent;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;

/**
 * This notification is used to ask an agent creation to a remote agent factory.
 */
public class AgentCreateRequest extends Notification
{

  /** Serialized state of the agent */
  private byte    agentState[];
  /**
   * Id. of agent to deploy. Used in case of unrecoverable error to report the
   * creation status.
   */
  private AgentId deploy;

  /** Id. of agent to reply to */
  private AgentId reply;

  /**
   * Creates an <code>AgentCreateRequest</code>
   * 
   * @param agent the agent to deploy
   * @throws IOException if the agent can't be serialized
   */
  public AgentCreateRequest(Agent agent) throws IOException
  {
    this(agent, null);
  }

  /**
   * Creates an <code>AgentCreateRequest</code>
   * 
   * @param agent the agent to deploy
   * @param reply the <code>AgentId</code> for the reply. If <code>null</code>
   *          response is not sent.
   * @throws IOException if the agent can't be serialized
   */
  public AgentCreateRequest(Agent agent, AgentId reply) throws IOException
  {
    super();

    this.reply = reply;
    this.deploy = agent.getId();

    ByteArrayOutputStream bos = new ByteArrayOutputStream();
    ObjectOutputStream oos = new ObjectOutputStream(bos);
    oos.writeObject(agent);
    oos.flush();
    agentState = bos.toByteArray();
  }

  /**
   * returns Serialized state of the agent.
   * 
   * @return Serialized state of the agent.
   */
  public byte[] getAgentState()
  {
    return agentState;
  }

  /**
   * Set agentState to <code>null</code>
   */
  protected void resetAgentState()
  {
    agentState = null;
  }

  /**
   * Returns Id. of agent to deploy. Used in case of unrecoverable error to
   * report the creation status.
   * 
   * @return Id. of agent to deploy. Used in case of unrecoverable error to
   *         report the creation status.
   */
  public AgentId getDeploy()
  {
    return deploy;
  }

  /**
   * Returns Id. of agent to reply to
   * 
   * @return Id. of agent to reply to
   */
  public AgentId getReply()
  {
    return reply;
  }

}