/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

/*
 * Parts of this code are copyright:
 * 
 * The contents of this file are subject to the Joram Public License, as defined
 * by the file JORAM_LICENSE.TXT
 * 
 * You may not use this file except in compliance with the License. You may
 * obtain a copy of the License on the Objectweb web site (www.objectweb.org).
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific terms governing rights and limitations under the License.
 * 
 * The Original Code is Joram, including the java packages fr.dyade.aaa.agent,
 * fr.dyade.aaa.util, fr.dyade.aaa.ip, fr.dyade.aaa.mom, and fr.dyade.aaa.joram,
 * released May 24, 2000.
 * 
 * The Initial Developer of the Original Code is Dyade. The Original Code and
 * portions created by Dyade are Copyright Bull and Copyright INRIA. All Rights
 * Reserved.
 * 
 * The present code contributor is INRIA Rhone-Alpes.
 */

package org.objectweb.dream.aaa.agent;

/**
 * DeleteAck - Acknowledge for deleting an agent
 */
public class DeleteAck extends Notification
{

  /** The returned status if the deletion was done */
  public static final int OK        = 0;
  /** The returned status if the deletion was denied */
  public static final int DENIED    = 1;
  /** The returned status if the deletion cached an exception */
  public static final int EXCEPTION = 2;

  private AgentId         agent     = null;

  private int             status    = OK;

  private Throwable       exc;

  /**
   * Default constructor, status is set to {@link #OK}.
   * 
   * @param agent the <code>AgentId</code> of the deleted agent
   */
  public DeleteAck(AgentId agent)
  {
    this.status = OK;
    this.agent = agent;
  }

  /**
   * Constructor when the deletion catch an exception, status is set to
   * {@link #EXCEPTION}.
   * 
   * @param agent the <code>AgentId</code> of the deleted agent.
   * @param exc the cached exception.
   */
  public DeleteAck(AgentId agent, Throwable exc)
  {
    this.status = EXCEPTION;
    this.agent = agent;
    this.exc = exc;
  }

  /**
   * Constructor for a specific status.
   * 
   * @param agent the <code>AgentId</code> of the deleted agent.
   * @param status the status.
   */
  public DeleteAck(AgentId agent, int status)
  {
    this.status = status;
    this.agent = agent;
  }

  /**
   * Returns the <code>AgentId</code> of the deleted agent.
   * 
   * @return the <code>AgentId</code> of the deleted agent.
   */
  public AgentId getAgent()
  {
    return agent;
  }

  /**
   * Returns the exception thrown if {@link #getStatus()}returns
   * {@link #EXCEPTION}
   * 
   * @return the exception thrown if {@link #getStatus()}returns
   *         {@link #EXCEPTION}
   */
  public Throwable getExc()
  {
    return exc;
  }

  /**
   * Returns the deletion status :{@link #OK},{@link #DENIED}or
   * {@link #EXCEPTION}
   * 
   * @return the deletion status :{@link #OK},{@link #DENIED}or
   *         {@link #EXCEPTION}
   */
  public int getStatus()
  {
    return status;
  }

}