/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

/*
 * Parts of this code are copyright:
 * 
 * The contents of this file are subject to the Joram Public License, as defined
 * by the file JORAM_LICENSE.TXT
 * 
 * You may not use this file except in compliance with the License. You may
 * obtain a copy of the License on the Objectweb web site (www.objectweb.org).
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific terms governing rights and limitations under the License.
 * 
 * The Original Code is Joram, including the java packages fr.dyade.aaa.agent,
 * fr.dyade.aaa.util, fr.dyade.aaa.ip, fr.dyade.aaa.mom, and fr.dyade.aaa.joram,
 * released May 24, 2000.
 * 
 * The Initial Developer of the Original Code is Dyade. The Original Code and
 * portions created by Dyade are Copyright Bull and Copyright INRIA. All Rights
 * Reserved.
 * 
 * The present code contributor is INRIA Rhone-Alpes.
 */

package org.objectweb.dream.aaa.agent;

/**
 * Notify by the engine to the sender of a notification when the corresponding
 * reaction throws an exception.
 */
public class ExceptionNotification extends Notification
{

  /** The target agent id. */
  protected AgentId      agent;
  /** The failing notification. */
  protected Notification not;
  /** The exception thrown. */
  protected Exception    exc;

  /**
   * Allocates a new <code>ExceptionNotification</code> notification.
   * 
   * @param agent The target agent id.
   * @param not The failing notification.
   * @param exc The exception thrown.
   */
  public ExceptionNotification(AgentId agent, Notification not, Exception exc)
  {
    this.agent = agent;
    this.not = not;
    this.exc = exc;
  }

  /**
   * Returns a string representation of this notification.
   * 
   * @return A string representation of this notification.
   */
  public String toString()
  {
    return "(" + super.toString() + ",agent=" + agent + ",not=" + not + ",exc="
        + exc + ")";
  }

  /**
   * returns the target agent id.
   * 
   * @return the target agent id.
   */
  public AgentId getAgent()
  {
    return agent;
  }

  /**
   * returns the exception thrown.
   * 
   * @return the exception thrown.
   */
  public Exception getExc()
  {
    return exc;
  }

  /**
   * returns the failing notification.
   * 
   * @return the failing notification.
   */
  public Notification getNot()
  {
    return not;
  }

}