/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.aaa.agent;

/**
 * Component interface to modify the local agent repository.
 */
public interface Repository
{

  /**
   * Returns the repository identifier of the component this interface belong
   * 
   * @return the repository identifier of the component this interface belong
   */
  short getRepositoryId();

  /**
   * Adds a new agent into the Event-based service
   * 
   * @param agentId the AgentId of the new Agent
   * @param agent the object Agent to add into the Agent's table
   */
  void addAgent(AgentId agentId, Agent agent);

  /**
   * Removes (delete) an agent of the Event-based service
   * 
   * @param agentId the AgentId of the Agent to remove (delete)
   * @throws UnknownAgentException if no Agent can be found for the specified id
   */
  void removeAgent(AgentId agentId) throws UnknownAgentException;
}