/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.adl.legacy;

import java.util.Map;

import org.objectweb.dream.adl.Checker;
import org.objectweb.dream.adl.Resolver;
import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.AbstractLoader;
import org.objectweb.fractal.adl.Definition;
import org.objectweb.fractal.adl.Node;
import org.objectweb.fractal.adl.components.Component;
import org.objectweb.fractal.adl.components.ComponentContainer;

/**
 *  
 */
public class LegacyLoader extends AbstractLoader
{

  /** The name of the {@link Checker }client interface */
  public static final String CHECKER_ITF_NAME  = "checker";

  /** The name of the {@link Resolver }client interface */
  public static final String RESOLVER_ITF_NAME = "resolver";

  private Checker            checkerItf;

  private Resolver           resolverItf;

  /**
   * @see org.objectweb.fractal.adl.Loader#load(java.lang.String, java.util.Map)
   */
  public Definition load(final String name, final Map context)
      throws ADLException
  {
    Object legacy = context.get("legacy:./");
    if (legacy == null)
    {
      throw new ADLException("Unable to find legacy component in context", null);
    }
    Definition d = clientLoader.load(name, context);
    checkNode((Node) d, legacy, "legacy:./", context);
    return d;
  }

  private void checkNode(final Node node, final Object legacy,
      final String path, final Map context) throws ADLException
  {
    if (legacy != null)
    {
      checkerItf.check(legacy, node);
      node.astSetDecoration("legacy", legacy);
    }
    if (node instanceof ComponentContainer)
    {
      ComponentContainer container = (ComponentContainer) node;
      Component[] tab = container.getComponents();
      for (int i = 0; i < tab.length; i++)
      {
        Component subComponent = tab[i];
        String componentPath = (path.endsWith("/")) ? path
            + subComponent.getName() : path + "/" + subComponent.getName();
        Object subLegacy = null;
        if (subComponent instanceof LegacyContainer)
        {
          // shearch legacy component
          Legacy l = ((LegacyContainer) subComponent).getLegacy();
          if (l != null)
          {
            subLegacy = context.get(componentPath);
            if (subLegacy == null && legacy != null)
            {
              if ("mandatory".equals(l.getContingency()))
              {
                try
                {
                  subLegacy = resolverItf.resolve(legacy, subComponent
                      .getName(), context);
                }
                catch (ComponentNotFoundException e)
                {
                  throw new ADLException(
                      "Unable to find mandatory legacy component.",
                      (Node) subComponent, e);
                }
              }
              else if ("optionnal".equals(l.getContingency()))
              {
                try
                {
                  subLegacy = resolverItf.resolve(legacy, subComponent
                      .getName(), context);
                }
                catch (ComponentNotFoundException e)
                {
                  // ignore, component is optional
                  break;
                }
              }
            }
          }
        }
        checkNode((Node) subComponent, subLegacy, componentPath, context);
      }
    }
    // TODO check binding between legacy component declared in the AST
  }

  // ------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // ------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{LOADER_BINDING, CHECKER_ITF_NAME, RESOLVER_ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#lookupFc(java.lang.String)
   */
  public Object lookupFc(String s)
  {
    if (CHECKER_ITF_NAME.equals(s))
    {
      return checkerItf;
    }
    else if (RESOLVER_ITF_NAME.equals(s))
    {
      return resolverItf;
    }
    else
    {
      return super.lookupFc(s);
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(java.lang.String,
   *      java.lang.Object)
   */
  public void bindFc(String s, Object o)
  {
    if (CHECKER_ITF_NAME.equals(s))
    {
      checkerItf = (Checker) o;
    }
    else if (RESOLVER_ITF_NAME.equals(s))
    {
      resolverItf = (Resolver) o;
    }
    else
    {
      super.bindFc(s, o);
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#unbindFc(java.lang.String)
   */
  public void unbindFc(String s)
  {
    if (CHECKER_ITF_NAME.equals(s))
    {
      checkerItf = null;
    }
    else if (RESOLVER_ITF_NAME.equals(s))
    {
      resolverItf = null;
    }
    else
    {
      super.unbindFc(s);
    }
  }

}