/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.aggregator;

import java.util.Map;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.Pull;
import org.objectweb.dream.PullException;
import org.objectweb.dream.message.ExtensibleMessage;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.MessageTypeImpl;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * This aggregator has a pull output on which it receives pull calls requiring
 * an aggregated message. The number of aggregated messages is specified has a
 * context parameter of the pull call. These messages are collected on its Pull
 * input.
 * 
 * @see PullPullAggregatorContextualKey
 */
public class PullPullAggregatorContextualImpl extends AbstractComponent
    implements
      Pull
{
  // ---------------------------------------------------------------------------
  // Client interfaces
  // ---------------------------------------------------------------------------

  protected Pull           inPullItf;
  protected MessageManager messageManagerItf;

  // ---------------------------------------------------------------------------
  // Implementation of the Pull interface
  // ---------------------------------------------------------------------------

  /**
   * @see Pull#pull(Map)
   */
  public Message pull(Map context) throws PullException
  {
    int nbMessageToAggregate = ((Integer) context.get(
        PullPullAggregatorContextualKey.KEY)).intValue();

    ExtensibleMessage outMessage = (ExtensibleMessage) messageManagerItf
        .createMessage(MessageTypeImpl.EMPTY_MESSAGE_TYPE);
    for (int i = 0; i < nbMessageToAggregate; i++)
    {
      outMessage.addSubMessage(inPullItf.pull(context));
    }
    return outMessage;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{MessageManager.ITF_NAME, Pull.IN_PULL_ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public synchronized void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
    else if (clientItfName.equals(Pull.IN_PULL_ITF_NAME))
    {
      inPullItf = (Pull) serverItf;
    }

  }
}