/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.channel;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.net.InetAddress;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.util.Util;

/**
 * Basic Implementation of {@link IPChannelSourceChunk}
 */
public class IPChannelSourceChunkImpl extends AbstractChunk
    implements
      IPChannelSourceChunk, Externalizable
{

  InetAddress ipChannelSourceAddr;
  int         ipChannelSourcePort;

  // ---------------------------------------------------------------------------
  // Implementation of IPChannelChunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see IPChannelSourceChunk#getChannelSourceAddr()
   */
  public InetAddress getChannelSourceAddr()
  {
    return ipChannelSourceAddr;
  }

  /**
   * @see IPChannelSourceChunk#setChannelSourceAddr(InetAddress)
   */
  public void setChannelSourceAddr(InetAddress addr)
  {
    ipChannelSourceAddr = addr;
  }

  /**
   * @see IPChannelSourceChunk#getChannelSourcePort()
   */
  public int getChannelSourcePort()
  {
    return ipChannelSourcePort;
  }

  /**
   * @see IPChannelSourceChunk#setChannelSourcePort(int)
   */
  public void setChannelSourcePort(int port)
  {
    ipChannelSourcePort = port;
  }

  // ---------------------------------------------------------------------------
  // Implementation of Chunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see Chunk#getType()
   */
  public ChunkType getType()
  {
    return IPChannelDestinationChunk.TYPE;
  }

  /**
   * @see Chunk#recycle()
   */
  public void recycle()
  {
    ipChannelSourceAddr = null;
  }

  /**
   * @see Chunk#transfertState(Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    IPChannelSourceChunk chunk = (IPChannelSourceChunk) newInstance;
    chunk.setChannelSourceAddr(getChannelSourceAddr());
    chunk.setChannelSourcePort(getChannelSourcePort());
  }

  // ---------------------------------------------------------------------------
  // Overriden methods
  // ---------------------------------------------------------------------------

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    return "IPChannelSourceChunkImpl(ipChannelSourceAddress="
        + ipChannelSourceAddr + ", ipChannelSourcePort="
        + ipChannelSourcePort + ")";
  }

  // ---------------------------------------------------------------------------
  // Implementation of the serialization methods
  // ---------------------------------------------------------------------------

  /**
   * @see Externalizable#readExternal(ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    ipChannelSourcePort = in.readInt();
    byte[] addr = Util.readExternalByteArray(in);
    ipChannelSourceAddr = InetAddress.getByAddress(addr);
  }

  /**
   * @see Externalizable#writeExternal(ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    out.writeInt(ipChannelSourcePort);
    Util.writeExternalByteArray(out, ipChannelSourceAddr.getAddress());
  }
}