/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */
package org.objectweb.dream.channel;

import org.objectweb.fractal.api.control.AttributeController;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Attribute controller for IP Accept Socket, It defines the listening port.
 */
public interface TCPAcceptSocketAttributeController extends AttributeController
{
  /** Default value of <code>openRetry</code> attribute. */
  int OPEN_RETRY_DEFAULT = 5;
  
  /**
   * Returns the listening port.
   * 
   * @return the <code>listeningPort</code> attribute's value.
   */
  int getListeningPort();

  /**
   * Sets the <code>listeningPort</code> attribute's value.
   * 
   * @param port the new <code>listeningPort</code> attribute's value.
   * @throws IllegalLifeCycleException cannot change port number if the
   *           component is started.
   * @see #getListeningPort()
   */
  void setListeningPort(int port) throws IllegalLifeCycleException;
  
  /**
   * Returns the number of attempts to open a {@link java.net.ServerSocket }
   * before aborting.
   * 
   * @return the <code>openRetry</code> attribute's value.
   */
  int getOpenRetry();

  /**
   * Sets the <code>openRetry</code> attribute's value.
   * 
   * @param retry the new <code>openRetry</code> attribute's value.
   * @see #getOpenRetry()
   */
  void setOpenRetry(int retry);

  /**
   * Returns <code>true</code> if the Nagle's algorithm is disabled on created
   * sockets.
   * 
   * @return the <code>tcpNoDelay</code> attribute's value.
   * @see java.net.Socket#setTcpNoDelay(boolean)
   */
  boolean getTcpNoDelay();

  /**
   * Sets the <code>tcpNoDelay</code> attribute's value.
   * 
   * @param tcpNoDelay the new <code>tcpNoDelay</code> attribute's value.
   * @see #getTcpNoDelay()
   */
  void setTcpNoDelay(boolean tcpNoDelay);

  /**
   * Returns the <code>SO_TIMEOUT</code> parameter setted on created sockets.
   * 
   * @return the <code>soTimeout</code> attribute's value.
   * @see java.net.Socket#setSoTimeout(int)
   */
  int getSoTimeout();

  /**
   * Sets the <code>soTimeout</code> attribute's value.
   * 
   * @param timeout the new <code>soTimeout</code> attribute's value.
   * @see #getSoTimeout()
   */
  void setSoTimeout(int timeout);

  /**
   * Returns the <code>SO_LINGER</code> parameter setted on created sockets. A
   * negative value disable the linger on close.
   * 
   * @return the <code>soLinger</code> attribute's value.
   * @see java.net.Socket#setSoLinger(boolean, int)
   */
  int getSoLinger();

  /**
   * Sets the <code>soLinger</code> attribute's value.
   * 
   * @param timeout the new <code>soLinger</code> attribute's value.
   */
  void setSoLinger(int timeout);
}
