/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.channel;

import java.io.IOException;

/**
 * Interface provided by component that can be used to wait for a byte over a
 * socket. Such component can be used to wait for an acknowledgment or for a
 * message request.
 */
public interface WaitByte
{
  /** The default name for interface of this type. */
  String ITF_NAME = "wait-byte";

  /**
   * Wait until a byte can be read on the given input.
   * 
   * @param input an input.
   * @return the byte read.
   * @throws IOException If an I/O error occurs
   * @see java.io.InputStream#read()
   */
  int waitByte(Object input) throws IOException;
}