/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.control.activity.task;

import java.util.Map;

/**
 * task stopped listener used by {@link BasicTaskActivationMixin }to
 * desactivate task.
 */
public class TaskActivationStoppedListener implements TaskStoppedListener
{

  protected TaskStoppedListener delegate;
  protected Map                 taskControls;

  /**
   * @param delegate another task listener to delegate (maybe <code>null</code>).
   * @param taskControls map containning task control. see
   *          {@link BasicTaskActivationMixin#_this_taskControls}.
   */
  public TaskActivationStoppedListener(TaskStoppedListener delegate,
      Map taskControls)
  {
    super();
    this.delegate = delegate;
    this.taskControls = taskControls;
  }

  /**
   * @see TaskStoppedListener#taskStopped(Task)
   */
  public void taskStopped(Task task)
  {
    taskControls.remove(task);
    if (delegate != null)
    {
      delegate.taskStopped(task);
    }
  }

}