/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): Matthieu Leclercq
 */

package org.objectweb.dream.control.activity.task;

import java.util.Map;

/**
 * A control interface to control tasks of the active component to which this
 * interface belongs.
 */
public interface TaskController
{

  /**
   * Returns the tasks of the component to which this interface belongs.
   * 
   * @return an array of task.
   */
  Task[] getTasks();

  /**
   * Adds a new task in this controller
   * 
   * @param task a new task.
   * @param hints registration hints. It can contains the name of the controller
   *          descriptor of the created component task, with the key
   *          <code>"taskControllerDesc"</code>. If no setted, use
   *          <code>primitiveTask</code> controller descriptor. <br>
   *          This parameter cannot be <code>null</code>.
   * @throws IllegalTaskException if the task component can't be registered.
   */
  void addTask(Task task, Map hints) throws IllegalTaskException;

  /**
   * Removes a task. The controller unregisters the task (if registered) and
   * remove it.
   * 
   * @param task the task to remove.
   * @throws NoSuchTaskException if the given task component is unknown.
   * @throws IllegalTaskException if the given task can't be unregistered.
   */
  void removeTask(Task task) throws NoSuchTaskException, IllegalTaskException;

  /**
   * Returns an interface that can be used to control a task (may be
   * <code>null</code> if no control is available for the task). The runtime
   * type of the interface depends on the implementation of the activity manager
   * and on the <code>hints</code> that have been given as paremeters of the
   * registration method of the activity manager.
   * 
   * @param task a task.
   * @return an interface that can be used to control a task (may be
   *         <code>null</code>)
   * @throws NoSuchTaskException if the given task component is unknown.
   * @throws IllegalTaskException if the given task is not currently registered.
   * @see #addTask(Task, Map)
   */
  Object getTaskControl(Task task) throws NoSuchTaskException,
      IllegalTaskException;
}