/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.control.lifecycle;

import java.lang.reflect.Method;

import org.objectweb.fractal.julia.asm.InterceptorCodeAdapter;
import org.objectweb.fractal.julia.asm.SimpleCodeGenerator;

/**
 * Interceptor generator for lifecycle interceptor. Use
 * {@link SimpleCodeGenerator }pre and post method are implemented by
 * <code>lifecycle-controller</code>. Pre and post method have the following
 * signature :<code>int addCurrentThread(String s)</code> and
 * <code>void removeCurrentThread(String s, int i)</code>.
 */
public class LifeCycleInterceptorGenerator extends SimpleCodeGenerator
{

  /**
   * @see SimpleCodeGenerator#getControllerInterfaceName()
   */
  protected String getControllerInterfaceName()
  {
    return "lifecycle-controller";
  }

  /**
   * @see SimpleCodeGenerator#getPreMethodName()
   */
  protected String getPreMethodName()
  {
    return "addCurrentThread";
  }

  /**
   * @see SimpleCodeGenerator#getPostMethodName()
   */
  protected String getPostMethodName()
  {
    return "removeCurrentThread";
  }

  /**
   * @see SimpleCodeGenerator#getContextType()
   */
  protected Class getContextType()
  {
    return Integer.TYPE;
  }

  /**
   * @see SimpleCodeGenerator#getMethodName(Method)
   */
  protected String getMethodName(Method m)
  {
    return "";
  }

  /**
   * @see org.objectweb.fractal.julia.asm.AbstractCodeGenerator#getInterceptionType(Method)
   */
  protected int getInterceptionType(Method m)
  {
    return InterceptorCodeAdapter.FINALLY;
  }
}