/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.message;

/**
 * This interface defined methods to dynamically add or remove chunks and sub
 * messages to this message. These methods are not defined in the
 * <code>Message</code> interface for efficency reasons.
 */
public interface ExtensibleMessage extends Message
{

  /**
   * Adds a chunk in this message.
   * 
   * @param name the name of the new chunk
   * @param chkType the type of the new chunk
   * @param chunk the chunk instance.
   * @throws ChunkAlreadyExistsException if this message has already a chunk
   *           with the same name
   */
  void addChunk(String name, ChunkType chkType, Object chunk)
      throws ChunkAlreadyExistsException;

  /**
   * Removes and returns the chunk with the specified name
   * 
   * @param name the name of the chunk to remove
   * @return the removed chunk or <code>null</code> if no chunk with the
   *         specified name can be found.
   */
  Object removeChunk(String name);

  /**
   * Adds a sub message in this message.
   * 
   * @param message the message to add.
   */
  void addSubMessage(Message message);

  /**
   * Removes the specified sub message.
   * 
   * @param message the message to be removed.
   * @return <code>true</code> if the message has been removed,
   *         <code>false</code> otherwise.
   */
  boolean removeSubMessage(Message message);

  /**
   * Removes every sub messages of this message.
   */
  void removeSubMessages();
}