/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.message;

import java.util.Iterator;

/**
 * Extends the MessageType interface and allows sub message types to be
 * retrieved using the sub message's name.
 * 
 * @see org.objectweb.dream.message.MessageNC
 */
public interface MessageTypeNC extends MessageType
{

  /**
   * Returns the type of the sub message having the specified name.
   * 
   * @param name the name of one of the message types returned by
   *          {@link #getSubMessageNames()}.
   * @return the type of the sub message having the specified name or
   *         <code>null</code> if no sub message with the specified name
   *         exists.
   */
  MessageType getSubMessageType(String name);

  /**
   * Returns an (eventually empty) array containing the sub message's names of
   * messages of this type.
   * 
   * @return an array containing the sub message's names of messages of this
   *         type.
   */
  String[] getSubMessageNames();

  /**
   * Returns an iterator over the sub message's names of messages of this type.
   * 
   * @return an iterator over the sub message's names of messages of this type.
   */
  Iterator getSubMessageNamesIterator();

  /**
   * Returns an (eventually empty) array containing the types of the unnamed sub
   * messages of messages of this type.
   * 
   * @return an array containing the types of the unnamed sub messages of
   *         messages of this type.
   */
  MessageType[] getUnnamedSubMessageTypes();

  /**
   * Returns an iterator over the types of the unnamed sub messages of messages
   * of this type.
   * 
   * @return an iterator over the types of the unnamed sub messages of messages
   *         of this type.
   */
  Iterator getUnnamedSubMessageTypesIterator();

}