/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.protocol.causality;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.util.Util;

/**
 * Basic implementation of {@link CausalityChunk}
 */
public class CausalityChunkImpl extends AbstractChunk
    implements
      CausalityChunk, Externalizable
{

  private Object causalityStamp;

  // ---------------------------------------------------------------------------
  // Implementation of the CausalityChunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.protocol.causality.CausalityChunk#getCausalityStamp()
   */
  public Object getCausalityStamp()
  {
    return causalityStamp;
  }

  /**
   * @see org.objectweb.dream.protocol.causality.CausalityChunk#setCausalityStamp(java.lang.Object)
   */
  public void setCausalityStamp(Object stamp)
  {
    causalityStamp = stamp;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Chunk interface
  // ---------------------------------------------------------------------------
  /**
   * @see org.objectweb.dream.message.Chunk#getType()
   */
  public ChunkType getType()
  {
    return TYPE;
  }

  /**
   * @see org.objectweb.dream.message.Chunk#transfertState(org.objectweb.dream.message.Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    ((CausalityChunk) newInstance).setCausalityStamp(getCausalityStamp());
  }

  /**
   * @see org.objectweb.dream.message.Chunk#recycle()
   */
  public void recycle()
  {
    causalityStamp = null;
  }
  
  // ---------------------------------------------------------------------------
  // Implementation of the serialization methods
  // ---------------------------------------------------------------------------

  /**
   * @see Externalizable#readExternal(ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    causalityStamp = Util.readObject(in);
  }

  /**
   * @see Externalizable#writeExternal(ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    Util.writeObject(out, causalityStamp);
  }

}