/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.protocol.causality;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * Causality message transformer attribute controller interface. It defines :
 * <ul>
 * <li>the name of the {@link org.objectweb.dream.protocol.ArrowChunk }
 * used to know the source or the destination process of messages.</li>
 * <li>the name of the {@link CausalityChunk }where the matrix clock, or the
 * updates are stored.</li>
 * </ul>
 */
public interface CausalityTransformerAttributeController
    extends
      AttributeController
{

  /**
   * Returns the name of the
   * {@link org.objectweb.dream.protocol.ArrowChunk }used to know the
   * source or the destination process of messages.
   * 
   * @return the name of the
   *         {@link org.objectweb.dream.protocol.ArrowChunk }used to know
   *         the source or the destination process of messages.
   */
  String getArrowChunkName();

  /**
   * Sets the name of the {@link org.objectweb.dream.protocol.ArrowChunk }
   * used to know the source or the destination process of messages.
   * 
   * @param arrowChunkName the name of the
   *          {@link org.objectweb.dream.protocol.ArrowChunk }used to know
   *          the source or the destination process of messages.
   */
  void setArrowChunkName(String arrowChunkName);

  /**
   * Returns the name of the {@link CausalityChunk }where the matrix clock, or
   * the updates are stored.
   * 
   * @return the name of the {@link CausalityChunk }where the matrix clock, or
   *         the updates are stored.
   */
  String getCausalityChunkName();

  /**
   * Sets the name of the {@link CausalityChunk }where the matrix clock, or the
   * updates are stored.
   * 
   * @param causalityChunkName the name of the {@link CausalityChunk }where the
   *          matrix clock, or the updates are stored.
   */
  void setCausalityChunkName(String causalityChunkName);

}