/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.protocol.utobcast;

import java.util.Map;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.Push;
import org.objectweb.dream.PushException;
import org.objectweb.dream.message.Message;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Implementation of the ACK component. This component forwards ACK messages to
 * the <code>PendingMessagesDataStructure</code> component.
 */
public class ACKImpl extends AbstractComponent implements Push
{

  // ---------------------------------------------------------------------------
  // Fields of this class
  // ---------------------------------------------------------------------------

  /**
   * The interface to forward ACK messages to the
   * <code>PendingMessageDataStructure</code> component.
   */
  protected ReceiveAck              receiveAckItf;

  // ---------------------------------------------------------------------------
  // Constructor
  // ---------------------------------------------------------------------------

  /**
   * Constructor.
   */
  public ACKImpl()
  {
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Push interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.Push#push(org.objectweb.dream.message.Message,
   *      java.util.Map)
   */
  public void push(Message message, Map context) throws PushException
  {
    // TODO Auto-generated method stub
  }

  // ---------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(java.lang.String,
   *      java.lang.Object)
   */
  public void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(ReceiveAck.ITF_NAME))
    {
      receiveAckItf = (ReceiveAck) serverItf;
    }

  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{ReceiveAck.ITF_NAME};
  }

}