/**
 * DREAM
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package org.objectweb.dream.protocol.utobcast;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * An attribute controller for the ProcessMembership component.
 */
public interface ProcessMembershipAttributeController
    extends
      AttributeController
{
  /**
   * Sets the blocking attribute. If this attribute is set to true, then the
   * ProcessMembership component is in blocking mode, which means that its
   * methods defined in the server interface it provides block until they can
   * return a meaningful result. For instance calling the
   * {@link ProcessMembership#getLeader()}method would block is no leader is
   * currently elected.
   * 
   * @param blocking the value to set.
   */
  void setBlocking(boolean blocking);

  /**
   * Returns <code>true</code> if the ProcessMembership component is in
   * blocking mode.
   * 
   * @return <code>true</code> if the ProcessMembership component is in
   *         blocking mode.
   * @see #setBlocking
   */
  boolean getBlocking();
}