/**
 * Dream
 * Copyright (C) 2003 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: matthieu.leclercq@inrialpes.fr
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.queue;

import java.util.Map;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.Pull;
import org.objectweb.dream.Push;
import org.objectweb.dream.message.Message;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * High performance implementation of a Push/Pull queue. This queue is not
 * thread safe and its <i>pull </i> interface is non blocking (return
 * <code>null</code> if the buffer is empty).
 */
public class PushPullQueueNotSynchronizedImpl extends AbstractComponent
    implements
      Push,
      Pull,
      PushQueuePrimitiveComponentAttributeController
{

  protected List listItf;
  protected int size = 0;
  
  /**
   * @see Push#push(Message, Map)
   */
  public void push(Message message, Map context)
  {
    size ++;
    listItf.add(message);
  }

  /**
   * @see Pull#pull(Map)
   */
  public Message pull(Map context)
  {
    if (listItf.isEmpty())
    {
      return null;
    }
    else
    {
      size --;
      return (Message) listItf.remove();
    }
  }

  /**
   * @see PushQueueAttributeController#getOverflowPolicy()
   */
  public String getOverflowPolicy()
  {
    return EXCEPTION_OVERFLOW_POLICY;
  }

  /**
   * @see PushQueueAttributeController#setOverflowPolicy(String)
   */
  public void setOverflowPolicy(String policy)
  {
    // do nothing, no overflow in this queue
  }

  /**
   * @see QueueAttributeController#getCurrentSize()
   */
  public int getCurrentSize()
  {
    return size;
  }

  /**
   * @see QueueAttributeController#getMaxCapacity()
   */
  public int getMaxCapacity()
  {
    return 0;
  }

  /**
   * @see QueueAttributeController#setMaxCapacity(int)
   */
  public void setMaxCapacity(int maxCapacity)
  {
    // do nothing no max capacity
  }

  // ---------------------------------------------------------------------------
  // Implementation of BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{List.ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(List.ITF_NAME))
    {
      listItf = (List) serverItf;
    }
  }
}