/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.util;

import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.api.Level;
import org.objectweb.util.monolog.api.Logger;

/**
 * A null logger each method is empty. This class can be used in a component if
 * there is no logger rather than test each logging code line if the logger is
 * <code>null</code>
 */
public class NullLogger implements Logger
{

  /**
   * The unique instance of this class.
   */
  public static final NullLogger NULL_LOGGER = new NullLogger();

  /**
   * Protected constructor, use {@link #NULL_LOGGER}rather construct a new
   * instance.
   */
  protected NullLogger()
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#setIntLevel(int)
   */
  public void setIntLevel(int arg0)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#setLevel(org.objectweb.util.monolog.api.Level)
   */
  public void setLevel(Level arg0)
  {
  }

  /**
   * returns {@link BasicLevel#FATAL}
   * 
   * @see org.objectweb.util.monolog.api.Logger#getCurrentIntLevel()
   */
  public int getCurrentIntLevel()
  {
    return BasicLevel.FATAL;
  }

  /**
   * returns {@link BasicLevel#LEVEL_FATAL}
   * 
   * @see org.objectweb.util.monolog.api.Logger#getCurrentLevel()
   */
  public Level getCurrentLevel()
  {
    return BasicLevel.LEVEL_FATAL;
  }

  /**
   * returns <code>false</code>
   * 
   * @see org.objectweb.util.monolog.api.Logger#isLoggable(int)
   */
  public boolean isLoggable(int arg0)
  {
    return false;
  }

  /**
   * returns <code>false</code>
   * 
   * @see org.objectweb.util.monolog.api.Logger#isLoggable(org.objectweb.util.monolog.api.Level)
   */
  public boolean isLoggable(Level arg0)
  {
    return false;
  }

  /**
   * returns <code>false</code>
   * 
   * @see org.objectweb.util.monolog.api.Logger#isOn()
   */
  public boolean isOn()
  {
    return false;
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(int, java.lang.Object)
   */
  public void log(int arg0, Object arg1)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(org.objectweb.util.monolog.api.Level,
   *      java.lang.Object)
   */
  public void log(Level arg0, Object arg1)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(int, java.lang.Object,
   *      java.lang.Throwable)
   */
  public void log(int arg0, Object arg1, Throwable arg2)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(org.objectweb.util.monolog.api.Level,
   *      java.lang.Object, java.lang.Throwable)
   */
  public void log(Level arg0, Object arg1, Throwable arg2)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(int, java.lang.Object,
   *      java.lang.Object, java.lang.Object)
   */
  public void log(int arg0, Object arg1, Object arg2, Object arg3)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(org.objectweb.util.monolog.api.Level,
   *      java.lang.Object, java.lang.Object, java.lang.Object)
   */
  public void log(Level arg0, Object arg1, Object arg2, Object arg3)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(int, java.lang.Object,
   *      java.lang.Throwable, java.lang.Object, java.lang.Object)
   */
  public void log(int arg0, Object arg1, Throwable arg2, Object arg3,
      Object arg4)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#log(org.objectweb.util.monolog.api.Level,
   *      java.lang.Object, java.lang.Throwable, java.lang.Object,
   *      java.lang.Object)
   */
  public void log(Level arg0, Object arg1, Throwable arg2, Object arg3,
      Object arg4)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#turnOn()
   */
  public void turnOn()
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Logger#turnOff()
   */
  public void turnOff()
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Handler#getName()
   */
  public String getName()
  {
    return "NullLogger";
  }

  /**
   * @see org.objectweb.util.monolog.api.Handler#setName(java.lang.String)
   */
  public void setName(String arg0)
  {
  }

  /**
   * @see org.objectweb.util.monolog.api.Handler#getType()
   */
  public String getType()
  {
    return "logger";
  }

  /**
   * @see org.objectweb.util.monolog.api.Handler#getAttributeNames()
   */
  public String[] getAttributeNames()
  {
    return new String[0];
  }

  /**
   * @see org.objectweb.util.monolog.api.Handler#getAttribute(java.lang.String)
   */
  public Object getAttribute(String arg0)
  {
    return null;
  }

  /**
   * @see org.objectweb.util.monolog.api.Handler#setAttribute(java.lang.String,
   *      java.lang.Object)
   */
  public Object setAttribute(String arg0, Object arg1)
  {
    return null;
  }
}