/**
 *
 */

package org.objectweb.util.monolog.api;

/**
 * Handler is an output. For example a
 * handler might be a console, a file, a socket, or a Logger.
 *
 * @author Sebastien Chassande-Barrioz
 */
public interface Handler {

	// Handler constant types //
	//------------------------//

	/**
	 * This constant is used to represent an handler which stores message into
	 * one file.
	 */
	byte FILE_HANDLER_TYPE = 1;

	/**
	 * This constant is used to represent an handler which prints message on
	 * a console.
	 */
	byte CONSOLE_HANDLER_TYPE = 2;

	/**
	 * This constant is used to represent an handler which stores message into
	 * several files.
	 */
	byte ROLLING_FILE_HANDLER_TYPE = 3;

	/**
	 * This constant is used to represent an handler which stores message into
	 * several files.
	 */
	byte GENERIC_HANDLER_TYPE = 4;

	/**
	 * This constant is used to represent an handler which is a Logger.
	 */
	byte LOGGER_HANDLER_TYPE = 5;


	// Handler attributes //
	//--------------------//

	String OUTPUT_ATTRIBUTE         = "output";
	String PATTERN_ATTRIBUTE        = "pattern";

	String APPEND_MODE_ATTRIBUTE    = "appendMode";

	String FILE_NUMBER_ATTRIBUTE    = "fileNumber";
	String MAX_SIZE_ATTRIBUTE       = "maxSize";


	/**
	 * It retrieves the name of the handler
	 */
	String getName();

	/**
	 * It assigns the name of the handler
	 */
	void setName(String name);

	/**
	 * It retrieves the Handler type
	 */
	byte getType();

	/**
	 * It retrieves the attributes of the handler
	 */
	String[] getAttributeNames();

	/**
	 * It retrieves the value of an attribute value of the handler.
	 * @param key is an attribute name
	 */
	Object getAttribute(String name);

	/**
	 * It assigns an attributte to the handler.
	 * @param key is the attribute name
	 * @param value is the attribute value
	 * @return the old value is the attribute was already defined
	 */
	Object setAttribute(String name, Object value);
}
